@@ -39,7 +39,6 @@ from rally import exceptions
 from rally import plugins
 from rally.task import atomic
 from rally.task.processing import charts
-from rally.task.processing import plot
 from rally.task import utils as tutils
 from rally.utils import strutils
 
@@ -123,12 +122,12 @@ OLD_TASK_RESULT_SCHEMA = {
 
 
 class FailedToLoadTask(exceptions.RallyException):
-    error_code = 472
+    error_code = 117
     msg_fmt = "Invalid %(source)s passed:\n\n\t %(msg)s"
 
 
 class FailedToLoadResults(exceptions.RallyException):
-    error_code = 529
+    error_code = 225
     msg_fmt = "ERROR: Invalid task result format in %(source)s\n\n\t%(msg)s"
 
 
@@ -329,7 +328,7 @@ class TaskCommands(object):
                   "starting. If you are running task with only one "
                   "scenario, soft abort will not help at all.")
 
-        api.task.abort(task_uuid=task_id, soft=soft, async=False)
+        api.task.abort(task_uuid=task_id, soft=soft, wait=True)
 
         print("Task %s successfully stopped." % task_id)
 
@@ -348,12 +347,27 @@ class TaskCommands(object):
     @cliutils.args("--iterations-data", dest="iterations_data",
                    action="store_true",
                    help="Print detailed results for each iteration.")
+    @cliutils.args("--filter-by", dest="filters", nargs="+", type=str,
+                   help="Filter the displayed workloads."
+                        "<sla-failures>: only display the failed workloads.\n"
+                        "<scenarios>: filter the workloads by scenarios.,"
+                        "scenarios=scenario_name1[,scenario_name2]...")
     @envutils.with_default_task_id
-    def detailed(self, api, task_id=None, iterations_data=False):
-        self._detailed(api, task_id, iterations_data)
+    def detailed(self, api, task_id=None, iterations_data=False,
+                 filters=None):
+        self._detailed(api, task_id, iterations_data, filters)
 
-    def _detailed(self, api, task_id=None, iterations_data=False):
+    def _detailed(self, api, task_id=None, iterations_data=False,
+                  filters=None):
         """Print detailed information about given task."""
+        scenarios_filter = []
+        only_sla_failures = False
+        for filter in filters or []:
+            if filter.startswith("scenario="):
+                filter_value = filter.split("=")[1]
+                scenarios_filter = filter_value.split(",")
+            if filter == "sla-failures":
+                only_sla_failures = True
 
         task = api.task.get(task_id=task_id, detailed=True)
 
@@ -384,6 +398,11 @@ class TaskCommands(object):
 
         for workload in itertools.chain(
                 *[s["workloads"] for s in task["subtasks"]]):
+            if scenarios_filter and workload["name"] not in scenarios_filter:
+                continue
+            if only_sla_failures and workload["pass_sla"]:
+                continue
+
             print("-" * 80)
             print()
             print("test scenario %s" % workload["name"])
@@ -676,7 +695,10 @@ class TaskCommands(object):
                     "title": "Task loaded from a file.",
                     "description": "Auto-ported from task format V1.",
                     "uuid": "n/a",
+                    "env_name": "n/a",
+                    "env_uuid": "n/a",
                     "tags": [],
+                    "status": consts.TaskStatus.FINISHED,
                     "subtasks": []}
 
             start_time = None
@@ -776,6 +798,8 @@ class TaskCommands(object):
                     msg = six.text_type(e)
                     raise exceptions.RallyException(
                         "ERROR: Invalid task result format\n\n\t%s" % msg)
+                task_result.setdefault("env_name", "n/a")
+                task_result.setdefault("env_uuid", "n/a")
                 for subtask in task_result["subtasks"]:
                     for workload in subtask["workloads"]:
                         workload.setdefault("contexts_results", [])
@@ -796,40 +820,21 @@ class TaskCommands(object):
                    help="Open the output in a browser.")
     @cliutils.args("--tasks", dest="tasks", nargs="+",
                    help="UUIDs of tasks, or JSON files with task results")
+    @cliutils.args("--html-static", dest="out_format",
+                   action="store_const", const="trends-html-static")
     @cliutils.suppress_warnings
     def trends(self, api, *args, **kwargs):
         """Generate workloads trends HTML report."""
-
         tasks = kwargs.get("tasks", []) or list(args)
-
         if not tasks:
             print("ERROR: At least one task must be specified",
                   file=sys.stderr)
             return 1
 
-        results = []
-        for task_id in tasks:
-            if os.path.exists(os.path.expanduser(task_id)):
-                results.extend(self._load_task_results_file(api, task_id))
-            elif strutils.is_uuid_like(task_id):
-                results.append(api.task.get(task_id=task_id, detailed=True))
-            else:
-                print("ERROR: Invalid UUID or file name passed: %s" % task_id,
-                      file=sys.stderr)
-                return 1
-
-        result = plot.trends(results)
-
-        out = kwargs.get("out")
-        if out:
-            output_file = os.path.expanduser(out)
-
-            with open(output_file, "w+") as f:
-                f.write(result)
-            if kwargs.get("open_it"):
-                webbrowser.open_new_tab("file://" + os.path.realpath(out))
-        else:
-            print(result)
+        self.export(api, tasks=tasks,
+                    output_type=kwargs.get("out_format", "trends-html"),
+                    output_dest=kwargs.get("out"),
+                    open_it=kwargs.get("open_it", False))
 
     @cliutils.deprecated_args("--tasks", dest="tasks", nargs="+",
                               release="0.10.0", alternative="--uuid")
@@ -853,15 +858,19 @@ class TaskCommands(object):
                                            "--type junit-xml"))
     @cliutils.args("--uuid", dest="tasks", nargs="+", type=str,
                    help="UUIDs of tasks or json reports of tasks")
+    @cliutils.args("--deployment", dest="deployment", type=str,
+                   help="Report all tasks with defined deployment",
+                   required=False)
     @envutils.default_from_global("tasks", envutils.ENV_TASK, "uuid")
     @cliutils.suppress_warnings
     def report(self, api, tasks=None, out=None,
-               open_it=False, out_format="html"):
+               open_it=False, out_format="html", deployment=None):
         """Generate a report for the specified task(s)."""
         self.export(api, tasks=tasks,
                     output_type=out_format,
                     output_dest=out,
-                    open_it=open_it)
+                    open_it=open_it,
+                    deployment=deployment)
 
     @cliutils.args("--force", action="store_true", help="force delete")
     @cliutils.args("--uuid", type=str, dest="task_id", nargs="*",
@@ -954,12 +963,20 @@ class TaskCommands(object):
                         "types) to save the report to or a connection string."
                         " It depends on the report type."
                    )
+    @cliutils.args("--deployment", dest="deployment", type=str,
+                   help="Report all tasks with defined deployment",
+                   required=False)
     @envutils.default_from_global("tasks", envutils.ENV_TASK, "uuid")
     @plugins.ensure_plugins_are_loaded
     def export(self, api, tasks=None, output_type=None, output_dest=None,
-               open_it=False):
+               open_it=False, deployment=None):
         """Export task results to the custom task's exporting system."""
-        tasks = isinstance(tasks, list) and tasks or [tasks]
+
+        if deployment is not None:
+            tasks = api.task.list(deployment=deployment, uuids_only=True)
+            tasks = [task["uuid"] for task in tasks]
+        else:
+            tasks = isinstance(tasks, list) and tasks or [tasks]
 
         exported_tasks = []
         for task_file_or_uuid in tasks:
